Files
dvc/tests/unit
Saugat Pachhai (सौगात) 896acedb07 data status: optimize printing status list
`--untracked-files` and `--unchanged` coupled with `--granular`
puts a lot of stress on `show_status`. Currently, with those options,
dvc spends ~26s on `_show_status` function.

Unhappy with the above result, I looked into improving the situation with
`console.out`. It did reduce that to 9s but it still felt like a lot.

Then I dropped to good old colorama, which dropped to 3s(term)/1.24(redirected).
I tested with buffering output which dropped this further to
~600ms(term)/~100ms(redirected).

This may seem like premature optimization, but this was preventing me
from figuring out perf issues in granular outputs, and I believe the
user should not be penalize for using feature that we already offer.
2022-07-25 17:47:23 +05:45
..
2022-07-08 21:37:38 +03:00
2022-07-08 21:37:38 +03:00
2022-03-21 13:47:44 +05:45
2022-07-08 21:37:38 +03:00
2021-09-03 14:37:24 +09:00
2022-07-21 19:34:04 +03:00
2022-07-12 13:53:46 +02:00
2021-11-22 17:33:12 +05:45
2022-05-30 16:51:35 +03:00
2018-12-28 19:58:25 +02:00
2022-05-30 16:51:35 +03:00
2022-01-19 12:22:07 +02:00
2021-11-10 00:52:48 +02:00